# Japanese Verb Conjugator

**NOTE**: Running tests should be done from `japaneseverbsconjugator` directory. Otherwise, you will likely get notifications that Python cannot find certain modules needed for import.